==> onlinepvt-0.0.2-py3-none-any.whl: onlinepvt/models/calculation_composition.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.calculation_block_info import CalculationBlockInfo
from ..models.component_type import ComponentType
from ..models.fluid_distribution_moment import FluidDistributionMoment
from ..types import UNSET, Unset

T = TypeVar("T", bound="CalculationComposition")


@attr.s(auto_attribs=True)
class CalculationComposition:
    """Holds composition information for a component"""

    component_id: Union[Unset, str] = UNSET
    component_name: Union[Unset, None, str] = UNSET
    component_type: Union[Unset, ComponentType] = UNSET
    mass: Union[Unset, float] = UNSET
    sorting_order: Union[Unset, int] = UNSET
    moment: Union[Unset, FluidDistributionMoment] = UNSET
    block_infos: Union[Unset, None, List[CalculationBlockInfo]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        component_id = self.component_id
        component_name = self.component_name
        component_type: Union[Unset, str] = UNSET
        if not isinstance(self.component_type, Unset):
            component_type = self.component_type.value

        mass = self.mass
        sorting_order = self.sorting_order
        moment: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.moment, Unset):
            moment = self.moment.to_dict()

        block_infos: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.block_infos, Unset):
            if self.block_infos is None:
                block_infos = None
            else:
                block_infos = []
                for block_infos_item_data in self.block_infos:
                    block_infos_item = block_infos_item_data.to_dict()

                    block_infos.append(block_infos_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if component_id is not UNSET:
            field_dict["componentId"] = component_id
        if component_name is not UNSET:
            field_dict["componentName"] = component_name
        if component_type is not UNSET:
            field_dict["componentType"] = component_type
        if mass is not UNSET:
            field_dict["mass"] = mass
        if sorting_order is not UNSET:
            field_dict["sortingOrder"] = sorting_order
        if moment is not UNSET:
            field_dict["moment"] = moment
        if block_infos is not UNSET:
            field_dict["blockInfos"] = block_infos

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        component_id = d.pop("componentId", UNSET)

        component_name = d.pop("componentName", UNSET)

        _component_type = d.pop("componentType", UNSET)
        component_type: Union[Unset, ComponentType]
        if isinstance(_component_type, Unset):
            component_type = UNSET
        else:
            component_type = ComponentType(_component_type)

        mass = d.pop("mass", UNSET)

        sorting_order = d.pop("sortingOrder", UNSET)

        _moment = d.pop("moment", UNSET)
        moment: Union[Unset, FluidDistributionMoment]
        if isinstance(_moment, Unset):
            moment = UNSET
        else:
            moment = FluidDistributionMoment.from_dict(_moment)

        block_infos = []
        _block_infos = d.pop("blockInfos", UNSET)
        for block_infos_item_data in _block_infos or []:
            block_infos_item = CalculationBlockInfo.from_dict(block_infos_item_data)

            block_infos.append(block_infos_item)

        calculation_composition = cls(
            component_id=component_id,
            component_name=component_name,
            component_type=component_type,
            mass=mass,
            sorting_order=sorting_order,
            moment=moment,
            block_infos=block_infos,
        )

        return calculation_composition

==> onlinepvt-0.0.9-py3-none-any.whl: onlinepvt/models/calculation_composition.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.api_fluid_distribution_moment import ApiFluidDistributionMoment
from ..models.calculation_block_info import CalculationBlockInfo
from ..models.component_type import ComponentType
from ..types import UNSET, Unset

T = TypeVar("T", bound="CalculationComposition")


@attr.s(auto_attribs=True)
class CalculationComposition:
    """Holds composition information for a component"""

    component_id: Union[Unset, str] = UNSET
    component_name: Union[Unset, None, str] = UNSET
    component_type: Union[Unset, ComponentType] = UNSET
    mass: Union[Unset, float] = UNSET
    sorting_order: Union[Unset, int] = UNSET
    moment: Union[Unset, ApiFluidDistributionMoment] = UNSET
    block_infos: Union[Unset, None, List[CalculationBlockInfo]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        component_id = self.component_id
        component_name = self.component_name
        component_type: Union[Unset, str] = UNSET
        if not isinstance(self.component_type, Unset):
            component_type = self.component_type.value
        mass = self.mass
        sorting_order = self.sorting_order
        moment: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.moment, Unset):
            moment = self.moment.to_dict()

        block_infos: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.block_infos, Unset):
            if self.block_infos is None:
                block_infos = None
            else:
                block_infos = []
                for block_infos_item_data in self.block_infos:
                    block_infos_item = block_infos_item_data.to_dict()

                    block_infos.append(block_infos_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if component_id is not UNSET:
            field_dict["componentId"] = component_id
        if component_name is not UNSET:
            field_dict["componentName"] = component_name
        if component_type is not UNSET:
            field_dict["componentType"] = component_type
        if mass is not UNSET:
            field_dict["mass"] = mass
        if sorting_order is not UNSET:
            field_dict["sortingOrder"] = sorting_order
        if moment is not UNSET:
            field_dict["moment"] = moment
        if block_infos is not UNSET:
            field_dict["blockInfos"] = block_infos

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        component_id = d.pop("componentId", UNSET)

        component_name = d.pop("componentName", UNSET)

        _component_type = d.pop("componentType", UNSET)
        component_type: Union[Unset, ComponentType]
        if isinstance(_component_type, Unset):
            component_type = UNSET
        else:
            component_type = ComponentType(_component_type)

        mass = d.pop("mass", UNSET)

        sorting_order = d.pop("sortingOrder", UNSET)

        _moment = d.pop("moment", UNSET)
        moment: Union[Unset, ApiFluidDistributionMoment]
        if isinstance(_moment, Unset):
            moment = UNSET
        else:
            moment = ApiFluidDistributionMoment.from_dict(_moment)

        block_infos = []
        _block_infos = d.pop("blockInfos", UNSET)
        for block_infos_item_data in _block_infos or []:
            block_infos_item = CalculationBlockInfo.from_dict(block_infos_item_data)

            block_infos.append(block_infos_item)

        calculation_composition = cls(
            component_id=component_id,
            component_name=component_name,
            component_type=component_type,
            mass=mass,
            sorting_order=sorting_order,
            moment=moment,
            block_infos=block_infos,
        )

        return calculation_composition
